from .polyfempy import Solver
from .polyfempy import ScalarFormulations
from .polyfempy import TensorFormulations

from .Settings import Settings

from .Problems import Franke
from .Problems import GenericScalar
from .Problems import Gravity
from .Problems import Torsion
from .Problems import GenericTensor
from .Problems import Flow
from .Problems import DrivenCavity
